JUStorageAdminScreen class
Full-screen admin UI for inspecting and editing just_storage data.
Provides three tabs:
- Standard — plain-text key-value entries
- Secure — AES-256-GCM encrypted entries
- Info — statistics, backend info, and danger zone
Usage:
Navigator.of(context).push(MaterialPageRoute(
builder: (_) => const JUStorageAdminScreen(),
));
Pass your own storage instances to inspect specific directories:
JUStorageAdminScreen(standard: myStorage, secure: mySecure)
Optionally supply a custom theme to override the app's theme:
JUStorageAdminScreen(theme: ThemeData(colorSchemeSeed: Colors.teal))
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- JUStorageAdminScreen
Constructors
- JUStorageAdminScreen({Key? key, ThemeData? theme, JustStandardStorage? standard, JustSecureStorage? secure})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secure → JustSecureStorage?
-
An existing secure storage instance to inspect.
When null, JUStorageAdminScreen creates its own via
JustStorage.encrypted().final - standard → JustStandardStorage?
-
An existing standard storage instance to inspect.
When null, JUStorageAdminScreen creates its own via
JustStorage.standard().final - theme → ThemeData?
-
Optional custom theme applied around the admin screen.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< JUStorageAdminScreen> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited