StorageProvider class

State manager for the just_storage admin UI.

Optionally accepts externally-created storage instances; when omitted, the provider creates its own instances via JustStorage.standard and JustStorage.encrypted (which resolve to the correct backend for the current platform).

Inheritance

Constructors

StorageProvider({JustStandardStorage? standard, JustSecureStorage? secure})

Properties

error String?
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
initialized bool
no setter
isLoading bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secureEntries Map<String, String>
no setter
standardEntries Map<String, String>
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearAll({required bool isSecure}) Future<void>
Removes all entries from either the standard or secure store.
deleteEntry(String key, {required bool isSecure}) Future<void>
Removes key from either the standard or secure store.
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
init() Future<void>
Creates storage instances (if not supplied externally) and loads all entries. Safe to call multiple times — subsequent calls are no-ops.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
refresh() Future<void>
Re-reads all entries from both storages and notifies listeners.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited
writeEntry(String key, String value, {required bool isSecure}) Future<void>
Writes keyvalue to either the standard or secure store.

Operators

operator ==(Object other) bool
The equality operator.
inherited